@@ -1,5 +1,5 @@
 package Strehler::API;
-$Strehler::API::VERSION = '1.6.2';
+$Strehler::API::VERSION = '1.6.3';
 use strict;
 use Dancer2 0.160000;
 use Dancer2::Serializer::JSON;
@@ -63,6 +63,27 @@ get '/:entity/slug/:slug' => sub {
     return serialize(\%data, $callback);
 };
 
+get '/:entity/schema' => sub {
+    my $entity = params->{entity};
+    my $callback = params->{'callback'} || undef;
+    my $class = Strehler::Helpers::class_from_entity($entity);
+    return pass if ! $class;
+    my @basic = $class->data_fields();
+    @basic = grep { $_ ne 'published' } @basic;
+    my @multilanguage = $class->multilang_data_fields();
+    my %data = ( 'basic' => \@basic,
+                 'multilanguage' => \@multilanguage );
+    if($callback)
+    {
+        content_type('application/javascript');
+    }
+    else
+    {
+        content_type('application/json');
+    }
+    return serialize(\%data, $callback);
+};
+
 get '/:entity/:id' => sub {
     my $entity = params->{entity};
     my $id = params->{'id'};
