@@ -1,5 +1,5 @@
 package Strehler::Admin;
-$Strehler::Admin::VERSION = '1.6.2';
+$Strehler::Admin::VERSION = '1.6.3';
 use strict;
 use Cwd 'abs_path';
 use Dancer2 0.160000;
@@ -42,6 +42,10 @@ set views => $root_path . 'views';
 
 ##### Homepage #####
 
+get '/' => sub {
+    my $redir = redirect(dancer_app->prefix);
+    return $redir;
+};
 get '' => sub {
     if(config->{'Strehler'}->{'dashboard_active'} && config->{'Strehler'}->{'dashboard_active'} == 1)
     {
@@ -76,7 +80,7 @@ any '/login' => sub {
             }
             else
             {
-                my $redir = redirect(dancer_app->prefix . '/');
+                my $redir = redirect(dancer_app->prefix);
                 return $redir;
             }
         }
@@ -92,7 +96,7 @@ get '/logout' => sub
 {
     session 'user' => undef;
     session 'role' => undef;
-    my $redir = redirect(dancer_app->prefix . '/');
+    my $redir = redirect(dancer_app->prefix);
     return $redir;
 };
 
@@ -801,7 +805,7 @@ post '/:entity/edit/:id' => sub
     my $message = 'quiet';
     if($form->submitted_and_valid)
     {
-        my $id = $class->save_form($id, $form, request->uploads());
+        my $id = $class->save_form($id, $form, request->uploads()); ## no critic qw(Variables::ProhibitReusedNames)
         if($id < 0)
         {
             return template "admin/message", { message => $class->error_message("edit", $id), backlink => dancer_app->prefix . '/' . $entity }; 
