@@ -1,5 +1,5 @@
 package Strehler::Element;
-$Strehler::Element::VERSION = '1.6.2';
+$Strehler::Element::VERSION = '1.6.3';
 use strict;
 use Carp 'carp';
 use Moo;
@@ -58,7 +58,21 @@ sub delete
     my $self = shift;
     my $children = $self->row->can($self->multilang_children());
     $self->row->$children->delete_all() if($children);
-    $self->row->delete();
+
+    return $self->row->delete();
+}
+
+sub category
+{
+    my $self = shift;
+    if($self->row->category)
+    {
+        return $self->row->category->category;
+    }
+    else
+    {
+        return undef;
+    }
 }
 
 sub get_attr
@@ -79,17 +93,6 @@ sub get_attr
             return $self->$accessor(undef);
         }
     }
-    if($attribute eq 'category')
-    {
-        if($self->row->category)
-        {
-            return $self->row->category->category;
-        }
-        else
-        {
-            return undef;
-        }
-    }
     if($attribute eq 'main-title')
     {
         return $self->main_title();
@@ -136,7 +139,7 @@ sub get_attr_multilang
     my $self = shift;
     my $attribute = shift;
     my $lang = shift;
-    my $bare = shift;
+    my $bare = shift || 0;
     my $accessor = $self->can($attribute);
     my $children = $self->row->can($self->multilang_children());
     return undef if not $children;
@@ -148,7 +151,14 @@ sub get_attr_multilang
     }
     if($accessor && ! $bare)
     {
-        return $self->$accessor($content_attribute, $lang);
+        if($content_attribute)
+        {
+            return $self->$accessor($content_attribute, $lang);
+        }
+        else
+        {
+            return $self->$accessor($lang);
+        }
     }
     if($content)
     {
@@ -245,54 +255,34 @@ sub max_category_order
 {
     my $self = shift;
     my $category_id = shift;
-    my $max;
+    my $max = 0;
+    my $max_found = 0;
     if($category_id)
     {
         my $category = Strehler::Meta::Category->new($category_id);
-        my $category_accessor = $self->category_accessor($category->row);
-        $max = $category->row->$category_accessor->search()->get_column('display_order')->max();
+        my $category_accessor = undef;
+        if($category)
+        {
+            $category_accessor = $self->category_accessor($category->row);
+            if($category_accessor)
+            {
+                $max = $category->row->$category_accessor->search()->get_column('display_order')->max();
+                $max_found = 1;
+            }
+         }
+        
     }
-    else
+    if(! $max_found)
     {
         $max = $self->get_schema()->resultset($self->ORMObj())->search()->get_column('display_order')->max();
     }
-    return $max || 0;
+    return $max;
 }
-
-sub get_data_fields
-{
-    my $self = shift;
-    if($self->data_fields())
-    {
-        return $self->data_fields();
-    }
-    else
-    {
-        return $self->row->result_source->columns;
-    }
-}
-
-sub get_multilang_data_fields
-{
-    my $self = shift;
-    my $children = shift;
-    if($self->multilang_data_fields())
-    {
-        return $self->multilang_data_fields();
-    }
-    else
-    {
-        return $self->row->$children->result_source->columns
-    }
-}
-
-
-
 sub get_basic_data
 {
     my $self = shift;
     my %data;
-    foreach my $c ($self->get_data_fields())
+    foreach my $c ($self->data_fields())
     {
         $data{$c} = $self->get_attr($c);
     }
@@ -306,16 +296,9 @@ sub get_ext_data
     my $language = shift;
     my %data;
     %data = $self->get_basic_data();
-    my $children = $self->row->can($self->multilang_children());
-    if($children)
+    foreach my $c ($self->multilang_data_fields())
     {
-        foreach my $c ($self->get_multilang_data_fields($children))
-        {
-            if($c ne 'id' && $c ne $self->item_type() && $c ne 'language')
-            {
-                $data{$c} = $self->get_attr_multilang($c, $language);
-            }
-        }
+        $data{$c} = $self->get_attr_multilang($c, $language);
     }
     return %data;
 }
@@ -890,7 +873,7 @@ sub make_select
     my $self = shift;
     my $list = $self->get_list( { entries_per_page => -1 } );
     my @category_values_for_select;
-    push @category_values_for_select, { value => undef, label => "-- seleziona --" }; 
+    push @category_values_for_select, { value => undef, label => "-- select --" }; 
     my @elements = @{$list->{to_view}};
     @elements = sort { lc($a->{'title'}) cmp lc($b->{'title'}) } @elements;
     for(@elements)
@@ -1141,7 +1124,7 @@ sub error_message
     my $self = shift;
     my $action = shift;
     my $code = shift;
-    if($code == '0')
+    if($code == 0)
     {
         return "OK";
     }
