@@ -1,5 +1,5 @@
 package Strehler::Element::Role::Configured;
-$Strehler::Element::Role::Configured::VERSION = '1.6.2';
+$Strehler::Element::Role::Configured::VERSION = '1.6.3';
 use strict;
 use Moo::Role;
 use Dancer2;
@@ -12,6 +12,7 @@ sub category_accessor
 {
     my $self = shift;
     my $category = shift;
+    return undef if ! $category;
     return $category->can($self->metaclass_data('category_accessor'));
 }
 
@@ -55,7 +56,7 @@ sub get_schema
 sub multilang
 {
     my $self = shift;
-    return 1 if $self->multilang_children() ne '';
+    return $self->multilang_children() ne '';
 }
 sub _property
 {
@@ -224,12 +225,30 @@ sub entity_data
 
 sub data_fields
 {
-    return undef;
+    my $self = shift;
+    return $self->get_schema()->resultset($self->ORMObj())->result_source->columns;
 }
 
 sub multilang_data_fields
 {
-    return undef;
+    my $self = shift;
+    if($self->multilang())
+    {
+        my @fields = $self->get_schema()->resultset($self->ORMObj())->related_resultset($self->multilang_children())->result_source->columns;
+        my @out;
+        foreach my $f (@fields)
+        {
+            if($f ne 'id' && $f ne $self->item_type() && $f ne 'language')
+            {
+                push @out, $f;
+            }
+        }
+        return @out;
+     }
+     else
+     {
+        return ();
+     }
 }
 sub custom_add_snippet
 {
