@@ -1,5 +1,5 @@
 package Strehler::Element::Role::Slugged;
-$Strehler::Element::Role::Slugged::VERSION = '1.6.2';
+$Strehler::Element::Role::Slugged::VERSION = '1.6.3';
 use strict;
 use Moo::Role;
 use Dancer2;
@@ -44,7 +44,13 @@ sub get_by_slug
     if($self->multilang_slug())
     {
         my $children = $self->multilang_children();
-        my @chapters = $self->get_schema()->resultset($self->ORMObj())->search({ $children . '.slug' => $slug, $children . '.language' => $language }, { join => $children });
+        my @chapters = $self->get_schema()->resultset($self->ORMObj())->search(
+            {
+                "$children.slug"     => $slug,
+                "$children.language" => $language,
+            },
+            { join => $children }
+        );
         $chapter = $chapters[0];
     }
     else
