@@ -1,5 +1,5 @@
 package Strehler::Meta::Category;
-$Strehler::Meta::Category::VERSION = '1.6.2';
+$Strehler::Meta::Category::VERSION = '1.6.3';
 use strict;
 use Moo;
 use Dancer2;
@@ -398,7 +398,7 @@ sub error_message
     my $self = shift;
     my $action = shift;
     my $code = shift;
-    if($code == '0')
+    if($code == 0)
     {
         return "OK";
     }
